@@ -17,10 +17,9 @@ from .formatters import DefaultHelpFormatter
 from .signatures import SignatureArguments
 from .typing import type_in
 from .jsonschema import ActionJsonSchema, supported_types
-from .jsonnet import ActionJsonnet, ActionJsonnetExtVars
+from .jsonnet import ActionJsonnet
 from .optionals import (
     import_jsonnet,
-    jsonschema_support,
     argcomplete_support,
     import_argcomplete,
     get_config_read_mode,
@@ -28,7 +27,6 @@ from .optionals import (
     TypeCastCompleterMethod,
 )
 from .actions import (
-    ActionYesNo,
     ActionEnum,
     ActionParser,
     ActionConfigFile,
@@ -164,12 +162,10 @@ class ArgumentParser(SignatureArguments, _ActionsContainer, argparse.ArgumentPar
         super().__init__(*args, **kwargs)
         if self.groups is None:
             self.groups = {}
-        if default_config_files is None:
-            default_config_files = []
         self.required_args = set()  # type: Set[str]
         self._stderr = sys.stderr
-        self._default_config_files = default_config_files
         self._parse_as_dict = parse_as_dict
+        self.default_config_files = default_config_files
         self.default_meta = default_meta
         self.default_env = default_env
         self.env_prefix = env_prefix
@@ -180,11 +176,6 @@ class ArgumentParser(SignatureArguments, _ActionsContainer, argparse.ArgumentPar
             self.add_argument(print_config, action=_ActionPrintConfig)
         if version is not None:
             self.add_argument('--version', action='version', version='%(prog)s '+version, help='Print version and exit.')
-        if len(default_config_files) > 0:
-            group = _ArgumentGroup(self,
-                                   title='default config file locations',
-                                   description=str(default_config_files))
-            self._action_groups = [group] + self._action_groups  # type: ignore
         if parser_mode not in {'yaml', 'jsonnet'}:
             raise ValueError('The only accepted values for parser_mode are {"yaml", "jsonnet"}.')
         if parser_mode == 'jsonnet':
@@ -769,10 +760,6 @@ class ArgumentParser(SignatureArguments, _ActionsContainer, argparse.ArgumentPar
         if not overwrite and os.path.isfile(path):
             raise ValueError('Refusing to overwrite existing file: '+path)
         path = Path(path, mode='fc')
-        if format not in {'parser_mode', 'yaml', 'json_indented', 'json'}:
-            raise ValueError('Unknown output format "'+str(format)+'".')
-        if format == 'parser_mode':
-            format = 'yaml' if self.parser_mode == 'yaml' else 'json_indented'
 
         dump_kwargs = {'format': format, 'skip_none': skip_none, 'skip_check': skip_check}
 
@@ -800,7 +787,7 @@ class ArgumentParser(SignatureArguments, _ActionsContainer, argparse.ArgumentPar
                         if '__path__' in val:
                             val_path = Path(os.path.join(dirname, os.path.basename(val['__path__']())), mode='fc')
                             if not overwrite and os.path.isfile(val_path()):
-                                raise ValueError('Refusing to overwrite existing file: '+val_path(absolute=False))
+                                raise ValueError('Refusing to overwrite existing file: '+str(val_path))
                             action = _find_action(self, kbase)
                             if isinstance(action, ActionParser):
                                 replace_keys[key] = val_path
@@ -808,14 +795,14 @@ class ArgumentParser(SignatureArguments, _ActionsContainer, argparse.ArgumentPar
                             elif isinstance(action, (ActionJsonSchema, ActionJsonnet)):
                                 replace_keys[key] = val_path
                                 val_out = strip_meta(val)
-                                if format.startswith('json') or isinstance(action, ActionJsonnet):
+                                if '__orig__' in val:
+                                    val_str = val['__orig__']
+                                elif str(val_path).lower().endswith('.json'):
                                     val_str = json.dumps(val_out, indent=2, sort_keys=True, ensure_ascii=False)+'\n'
                                 else:
                                     val_str = yaml.dump(val_out, default_flow_style=False, allow_unicode=True)
                                 with open(val_path(), 'w') as f:
                                     f.write(val_str)
-                            #else:
-                            #    save_paths(val, kbase)
                         else:
                             save_paths(val, kbase)
                 for key, val in replace_keys.items():
@@ -888,7 +875,7 @@ class ArgumentParser(SignatureArguments, _ActionsContainer, argparse.ArgumentPar
         self._logger.info('Loaded default values from parser.')
 
         default_config_files = []  # type: List[str]
-        for pattern in self._default_config_files:
+        for pattern in self.default_config_files:
             default_config_files += glob.glob(os.path.expanduser(pattern))
         if len(default_config_files) > 0:
             default_config_file = Path(default_config_files[0], mode=get_config_read_mode())
@@ -1164,6 +1151,37 @@ class ArgumentParser(SignatureArguments, _ActionsContainer, argparse.ArgumentPar
             raise ValueError('error_handler can be either a Callable or None.')
 
 
+    @property
+    def default_config_files(self):
+        """Default config file locations.
+
+        :getter: Returns the current default config file locations.
+        :setter: Sets new default config file locations, e.g. :code:`['~/.config/myapp/*.yaml']`.
+
+        Raises:
+            ValueError: If an invalid value is given.
+        """
+        return self._default_config_files
+
+
+    @default_config_files.setter
+    def default_config_files(self, default_config_files:Optional[List[str]]):
+        if default_config_files is None:
+            self._default_config_files = []
+        elif isinstance(default_config_files, list) and all(isinstance(x, str) for x in default_config_files):
+            self._default_config_files = default_config_files
+        else:
+            raise ValueError('default_config_files has to be None or List[str].')
+
+        if len(self._default_config_files) > 0:
+            group_title = 'default config file locations'
+            group = next((g for g in self._action_groups if g.title == group_title), None)
+            if group is None:
+                group = _ArgumentGroup(self, title=group_title)
+                self._action_groups = [group] + self._action_groups  # type: ignore
+            group.description = str(self._default_config_files)
+
+
     @property
     def default_env(self):
         """Whether by default environment variables parsing is enabled.
